pub struct OrderInitializedSpec {Show 33 fields
pub trader_id: TraderId,
pub strategy_id: StrategyId,
pub instrument_id: InstrumentId,
pub client_order_id: ClientOrderId,
pub order_side: OrderSide,
pub order_type: OrderType,
pub quantity: Quantity,
pub time_in_force: TimeInForce,
pub post_only: bool,
pub reduce_only: bool,
pub quote_quantity: bool,
pub reconciliation: bool,
pub event_id: UUID4,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
pub price: Option<Price>,
pub trigger_price: Option<Price>,
pub trigger_type: Option<TriggerType>,
pub limit_offset: Option<Decimal>,
pub trailing_offset: Option<Decimal>,
pub trailing_offset_type: Option<TrailingOffsetType>,
pub expire_time: Option<UnixNanos>,
pub display_qty: Option<Quantity>,
pub emulation_trigger: Option<TriggerType>,
pub trigger_instrument_id: Option<InstrumentId>,
pub contingency_type: Option<ContingencyType>,
pub order_list_id: Option<OrderListId>,
pub linked_order_ids: Option<Vec<ClientOrderId>>,
pub parent_order_id: Option<ClientOrderId>,
pub exec_algorithm_id: Option<ExecAlgorithmId>,
pub exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>,
pub exec_spawn_id: Option<ClientOrderId>,
pub tags: Option<Vec<Ustr>>,
}Expand description
Test-only fluent spec for OrderInitialized.
All fields carry sensible defaults so callers only set what differs.
build() constructs the event through OrderInitialized::new so any future invariants
added to the production constructor are exercised by tests built on this spec.
Fields
trader_id: TraderIdstrategy_id: StrategyIdinstrument_id: InstrumentIdclient_order_id: ClientOrderIdorder_side: OrderSideorder_type: OrderTypequantity: Quantitytime_in_force: TimeInForcepost_only: boolreduce_only: boolquote_quantity: boolreconciliation: boolevent_id: UUID4ts_event: UnixNanosts_init: UnixNanosprice: Option<Price>trigger_price: Option<Price>trigger_type: Option<TriggerType>limit_offset: Option<Decimal>trailing_offset: Option<Decimal>trailing_offset_type: Option<TrailingOffsetType>expire_time: Option<UnixNanos>display_qty: Option<Quantity>emulation_trigger: Option<TriggerType>trigger_instrument_id: Option<InstrumentId>contingency_type: Option<ContingencyType>order_list_id: Option<OrderListId>linked_order_ids: Option<Vec<ClientOrderId>>parent_order_id: Option<ClientOrderId>exec_algorithm_id: Option<ExecAlgorithmId>exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>exec_spawn_id: Option<ClientOrderId>Implementations
Sourceimpl OrderInitializedSpec
impl OrderInitializedSpec
Sourcepub fn builder() -> OrderInitializedSpecBuilder
pub fn builder() -> OrderInitializedSpecBuilder
Create an instance of OrderInitializedSpec using the builder syntax